@@ -250,6 +250,10 @@ Class Definitions
 ..  autofunction:: preParse
 """
 from __future__ import print_function
+from itertools import chain
+from itertools import count
+from itertools import izip
+from itertools import repeat
 import logging
 
 # This is only to give us access a default Factory.
@@ -666,19 +670,21 @@ class Segment( Parser ):
         :param segments: list of SegmentTokens for the current message.
         :returns: yields a single parsed Segment or raises StopIteration
         """
-        try:
-            if self.repeat.startswith(">"):
-                repeat = 999
-            else:
-                repeat = int(self.repeat)
-        except:
-            repeat = 1
-        for i in range(repeat):
+        if isinstance(self.repeat, int):
+            length_loop = xrange(self.repeat)
+        elif self.repeat.startswith(">"):
+            length_loop = count()
+        else:
+            length_loop = xrange(int(self.repeat) if self.repeat.isdigit() else 1)
+
+        required_loop = chain([self.required], repeat(False))
+
+        for required, _ in izip(required_loop, length_loop):
             if self.match( segments[0] ):
                 compPunct= self.getMessage().compPunct
                 theSegment= self.theFactory.makeSegment( segments.pop(0), compPunct, self )
                 yield theSegment
-            elif self.situational or self.notused:
+            elif not required:
                 raise StopIteration
             else:
                 error= ParseError(
@@ -821,12 +827,14 @@ class Message( Parser ):
             SegmentToken( seg.split(eltPunct) )
                 for seg in msg.split( segPunct )
                     if len(seg) > 0]
-    def unmarshall( self, message, factory=MessageFactory ):
+    def unmarshall(self, message, factory=MessageFactory, ignoreExtra=False):
         """Unmarshall the text version of an X12 message
         into a structure defined by the given factory.
         
         :param message: X12 source text
         :param factory: A message instance Factory, by default :class:`X12.message.Factory`.
+        :param ignoreExtra: If True, extra segments are ignored instead of
+            causing a parse error.
         :returns: :class:`X12.message.X12Message` structure
         :raises ParseError: if the message does not fit this parser's structure.
         """
@@ -842,7 +850,7 @@ class Message( Parser ):
             raise ex
         theMssg= self.factory.makeMessage( self.name )
         self.getParts( self.segmentTokens, theMssg )
-        if len(self.segmentTokens) != 0:
+        if len(self.segmentTokens) != 0 and not ignoreExtra:
             names= ", ".join( s[0] for s in self.segmentTokens )
             raise ParseError(
                 "Extra segments {0!r}".format( names ),
